function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useEffect, useRef } from 'react';
import Empty from './Empty';
import PropTypes from 'prop-types';
import ReactEchartsCore from 'echarts-for-react/lib/core';
import echarts from 'echarts/lib/echarts';
import 'echarts/lib/chart/pie';
import 'echarts/lib/component/legend';
import 'echarts/lib/component/legendScroll';
import 'echarts/lib/component/tooltip';
import 'echarts/lib/component/title';
import 'echarts/lib/component/markPoint';
import 'echarts/lib/component/markLine';
import 'echarts/lib/component/markArea';
import 'echarts/lib/component/dataZoom';
import { summate } from '../utils';
var index = 0; // 高亮索引

var PieChart = function PieChart(_ref) {
  var _legend;

  var chartData = _ref.chartData,
      radius = _ref.radius,
      showTitle = _ref.showTitle,
      rest = _objectWithoutProperties(_ref, ["chartData", "radius", "showTitle"]);

  var pieRef = useRef(null);
  useEffect(function () {
    var pieInstance = pieRef.current.getEchartsInstance();
    console.log('index', index);
    pieInstance.dispatchAction({
      type: 'highlight',
      seriesIndex: index,
      dataIndex: index
    });
    pieInstance.on('mouseover', function (e) {
      if (e.dataIndex != index) {
        this.dispatchAction({
          type: 'downplay',
          seriesIndex: 0,
          dataIndex: index
        });
      } else {
        this.dispatchAction({
          type: 'downplay',
          seriesIndex: 0,
          dataIndex: 0
        });
      }
    });
    pieInstance.on('mouseout', function (e) {
      index = e.dataIndex;
      this.dispatchAction({
        type: 'highlight',
        seriesIndex: 0,
        dataIndex: e.dataIndex
      });
    });
    return function () {
      pieInstance.off('mouseover');
      pieInstance.off('mouseout');
    };
  }, [chartData]);
  var option = {
    title: {
      text: chartData.title.text,
      show: showTitle
    },
    tooltip: {
      trigger: 'item',
      formatter: '{a} <br/>{b}: {c} ({d}%)'
    },
    legend: (_legend = {
      top: 'bottom',
      type: 'scroll',
      orient: 'vertical',
      right: '10%'
    }, _defineProperty(_legend, "top", 'center'), _defineProperty(_legend, "itemGap", 15), _defineProperty(_legend, "selectedMode", false), _defineProperty(_legend, "icon", 'pin'), _defineProperty(_legend, "textStyle", {
      fontSize: 14,
      rich: {
        name: {
          color: '#262A30'
        },
        value: {
          padding: [0, 5, 0, 5]
        },
        percent: {
          color: '#00A9FF'
        }
      }
    }), _defineProperty(_legend, "formatter", function formatter(name) {
      var total = summate(chartData.series[0].data);
      var res = chartData.series[0].data.filter(function (v) {
        return v.name === name;
      });
      var percent = (res[0].value * 100 / total).toFixed(2);
      return '{name| ' + name + '} {value|' + res[0].value + '} {percent|' + percent + '%}';
    }), _legend),
    toolbox: {
      show: false
    },
    series: [{
      name: chartData.series.length ? chartData.series[0].name : '',
      type: 'pie',
      radius: radius,
      selectedMode: 'single',
      // center: ['50%', '60%'],
      data: chartData.series.length ? chartData.series[0].data : [],
      emphasis: {
        label: {
          show: true,
          fontSize: 20,
          fontWeight: 'bold',
          formatter: '{per|{d}%}\n{name|{b}}',
          textStyle: {
            rich: {
              per: {
                fontSize: 18,
                color: '#959BA3',
                lineHeight: 30
              },
              name: {
                fontSize: 14,
                fontWeight: 'normal',
                color: '#41A6FE'
              }
            }
          }
        }
      },
      labelLine: {
        show: false
      },
      label: {
        formatter: '{b} {d}% \n',
        show: false,
        padding: [0, 0],
        position: 'center'
      }
    }]
  };

  if (!chartData.series.length) {
    return /*#__PURE__*/React.createElement(Empty, {
      image: Empty.PRESENTED_IMAGE_SIMPLE
    });
  }

  return /*#__PURE__*/React.createElement(ReactEchartsCore, _extends({
    echarts: echarts,
    notMerge: true,
    option: option
  }, rest, {
    ref: pieRef
  }));
};

PieChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  radius: PropTypes.array,
  showTitle: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  chartData: PropTypes.object
};
PieChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  showTitle: false,
  radius: ['35%', '60%'],
  chartData: {
    title: {
      text: ''
    },
    series: [{
      center: ['25%', '30%'],
      data: [{
        value: 335,
        name: '直接访问'
      }, {
        value: 310,
        name: '邮件营销'
      }, {
        value: 234,
        name: '联盟广告'
      }, {
        value: 135,
        name: '视频广告'
      }, {
        value: 1548,
        name: '搜索引擎'
      }]
    }]
  }
};
export default PieChart;