import React, { forwardRef } from 'react'
import PropTypes from 'prop-types'

import ReactEchartsCore from 'echarts-for-react/lib/core'
import echarts from 'echarts/lib/echarts'
import 'echarts/lib/chart/line'
import 'echarts/lib/chart/lines'
import 'echarts/lib/component/legend'
import 'echarts/lib/component/legendScroll'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/markPoint'
import 'echarts/lib/component/markLine'
import 'echarts/lib/component/markArea'
import 'echarts/lib/component/dataZoom'

import { formatNumber } from '../utils'

// 节点处出现数据
const label = {
  show: true,
  position: 'top',
  textStyle: {
    color: '#000',
  },
}
const dataZoom = [
  {
    // 添加X轴滚动条
    realtime: true,
    show: true,
    start: 0,
    end: 60,
    height: 16,
    // handleSize: 8
  },
  {
    type: 'inside',
    realtime: true,
    start: 0,
    end: 60,
  },
]

const LineChart = forwardRef(({ chartData, showTitle, interval, showLabel, ...rest }, ref) => {
  const option = {
    title: {
      text: chartData.title.text,
      show: showTitle,

      textStyle: {
        fontSize: 16,
        fontWeight: 500,
        color: 'rgba(0, 0, 0, 0.85)',
      },
    },
    tooltip: {
      trigger: 'axis',
      // axisPointer: {
      //   type: 'cross'
      // }
    },
    legend: {
      left: 4,
      top: showTitle ? 27 : 'top',
      type: 'scroll',
      icon: 'roundRect',
      padding: 0,
      itemHeight: 2,
      itemWidth: 12,
    },
    toolbox: {
      show: false,
    },
    grid: {
      top: showTitle || showLabel ? 66 : 36,
      left: 0,
      right: 10,
      bottom: 0,
      containLabel: true,
    },

    xAxis: {
      type: 'category',
      axisLine: {
        lineStyle: {
          color: '#ccd6eb',
        },
      },
      axisLabel: {
        interval: interval ? 'auto' : 0,
      },
      boundaryGap: true,
      data: chartData.xAxis[0].data,
    },

    yAxis: {
      type: 'value',
      minInterval: 1,
      axisLine: { show: false },
      splitLine: {
        show: true,
        lineStyle: {
          type: 'dashed',
        },
      },

      axisTick: {
        show: false,
      },
    },

    series: chartData.series || [],
  }
  let targetArr = []
  option.series.forEach(item => {
    if (showLabel) {
      item.label = {
        ...label,
        formatter: chartData.isRate
          ? '{c}%'
          : function({ value }) {
              // 千分位分隔符

              return `${formatNumber(value)}`
            },
      }
    }
    item.type = 'line'
    // item.symbol = "none" // 此处配置 不显示点
    // item.areaStyle={}
    targetArr = targetArr.concat(item.data)
  })

  if (chartData.xAxis[0].data.length > 25) {
    option.dataZoom = dataZoom
  } else {
    option.dataZoom = []
  }

  if (!targetArr.length) {
    // 数据为空时展示
    option.yAxis.max = 5000000
    option.yAxis.min = 0
  } else {
    option.yAxis.max = null
    option.yAxis.min = null
  }

  return <ReactEchartsCore echarts={echarts} notMerge option={option} ref={ref} {...rest} />
})

LineChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  interval: PropTypes.bool,
  showTitle: PropTypes.bool,
  showLabel: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  chartData: PropTypes.object,
}

LineChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  showTitle: false,
  interval: true,
  showLabel: false,
  chartData: {
    title: { text: '' },
    series: [
      {
        data: [],
        type: 'line',
      },
    ],
    xAxis: [{ data: [] }],
  },
}

export default LineChart
