import React, { forwardRef } from 'react'
import Empty from './Empty'
import PropTypes from 'prop-types'

import ReactEchartsCore from 'echarts-for-react/lib/core'

import echarts from 'echarts/lib/echarts'
import 'echarts/lib/chart/pie'
import 'echarts/lib/component/legend'
import 'echarts/lib/component/legendScroll'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/markPoint'
import 'echarts/lib/component/markLine'
import 'echarts/lib/component/markArea'
import 'echarts/lib/component/dataZoom'

const PieChart = forwardRef(({ chartData, radius, showTitle, ...rest }, ref) => {
  const option = {
    title: {
      text: chartData.title.text,
      show: showTitle,
    },
    tooltip: {
      trigger: 'item',
      formatter: '{a} <br/>{b}: {c} ({d}%)',
    },
    legend: {
      top: 'bottom',
      type: 'scroll',
    },
    toolbox: {
      show: false,
    },

    series: [
      {
        name: chartData.series.length ? chartData.series[0].name : '',
        type: 'pie',
        radius,
        selectedMode: 'single',
        // center: ['50%', '60%'],
        data: chartData.series.length ? chartData.series[0].data : [],

        label: {
          formatter: '{b} {d}% \n',
          padding: [0, 0],
        },
      },
    ],
  }

  if (!chartData.series.length) {
    return <Empty image={Empty.PRESENTED_IMAGE_SIMPLE} />
  }

  return <ReactEchartsCore echarts={echarts} notMerge ref={ref} option={option} {...rest} />
})

PieChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  radius: PropTypes.array,
  showTitle: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  chartData: PropTypes.object,
}

PieChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  showTitle: false,
  radius: ['35%', '50%'],
  chartData: {
    title: { text: '' },
    series: [
      {
        data: [],
      },
    ],
  },
}

export default PieChart
